==> drools-compiler-0.3.0-sources.jar: org/drools/compiler/lang/descr/ExprConstraintDescr.java <==
/*
 * Copyright 2005 Red Hat, Inc. and/or its affiliates.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.drools.compiler.lang.descr;

/**
 * This represents a constraint in a pattern defined by an arbitrary
 * expression. The constraint can be any valid java/mvel expression.
 */
public class ExprConstraintDescr extends BaseDescr implements ExpressionDescr {

    private static final long serialVersionUID = 520l;
    
    public static enum Type {
        NAMED, POSITIONAL;
    }
    
    private Type type = Type.NAMED;
    private int position = -1;

    public ExprConstraintDescr() { }
    
    public ExprConstraintDescr(final String expr) {
        setText( expr );
    }
    
    public void setExpression( final String expr ) {
        setText( expr );
    }
    
    public String getExpression( ) {
        return getText();
    }

    /**
     * @return the type
     */
    public Type getType() {
        return type;
    }

    /**
     * @param type the type to set
     */
    public void setType( Type type ) {
        this.type = type;
    }

    /**
     * @return the position
     */
    public int getPosition() {
        return position;
    }

    /**
     * @param position the position to set
     */
    public void setPosition( int position ) {
        this.position = position;
    }
    
    @Override
    public String toString() {
        return getText();
    }

    
}

==> drools-compiler-0.8.1-sources.jar: org/drools/compiler/lang/descr/ExprConstraintDescr.java <==
/*
 * Copyright 2005 Red Hat, Inc. and/or its affiliates.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.drools.compiler.lang.descr;

/**
 * This represents a constraint in a pattern defined by an arbitrary
 * expression. The constraint can be any valid java/mvel expression.
 */
public class ExprConstraintDescr extends BaseDescr implements ExpressionDescr {

    private static final long serialVersionUID = 520l;
    private boolean negated = false;

    public static enum Type {
        NAMED, POSITIONAL;
    }
    
    private Type type = Type.NAMED;
    private int position = -1;

    public ExprConstraintDescr() { }
    
    public ExprConstraintDescr(final String expr) {
        setText( expr );
    }
    
    public void setExpression( final String expr ) {
        setText( expr );
    }
    
    public String getExpression( ) {
        return getText();
    }

    /**
     * @return the type
     */
    public Type getType() {
        return type;
    }

    /**
     * @param type the type to set
     */
    public void setType( Type type ) {
        this.type = type;
    }

    /**
     * @return the position
     */
    public int getPosition() {
        return position;
    }

    /**
     * @param position the position to set
     */
    public void setPosition( int position ) {
        this.position = position;
    }
    
    @Override
    public String toString() {
        return getText();
    }

    @Override
    public BaseDescr negate() {
        negated = true;
        return this;
    }

    @Override
    public boolean isNegated() {
        return negated;
    }
}
